@@ -1,4 +1,5 @@
 import base64
+import io
 import logging
 import os
 import time
@@ -22,6 +23,8 @@ async def pipeline_route(request: Request) -> Response:
     start = time.time()
     payload = await request.body()
     task = os.environ["TASK"]
+    if os.getenv("DEBUG", "0") in {"1", "true"}:
+        pipe = request.app.get_pipeline()
     try:
         pipe = request.app.get_pipeline()
         try:
@@ -64,6 +67,8 @@ def call_pipe(pipe: Any, inputs, params: Dict, start: float) -> Response:
 
     status_code = 200
     n_characters = 0
+    if os.getenv("DEBUG", "0") in {"1", "true"}:
+        outputs = pipe(inputs)
     try:
         outputs = pipe(inputs)
         n_characters = get_input_characters(inputs)
@@ -108,6 +113,17 @@ def call_pipe(pipe: Any, inputs, params: Dict, start: float) -> Response:
                     }
                 )
             return JSONResponse(items, headers=headers, status_code=status_code)
+        elif task == "text-to-image":
+            buf = io.BytesIO()
+            outputs.save(buf, format="JPEG")
+            buf.seek(0)
+            img_bytes = buf.read()
+            return Response(
+                img_bytes,
+                headers=headers,
+                status_code=200,
+                media_type="image/jpeg",
+            )
 
     return JSONResponse(
         outputs,
