@@ -207,27 +207,56 @@ def check_inputs(inputs, tag):
         raise ValueError(f"{tag} is not a valid pipeline.")
 
 
+AUDIO_INPUTS = {
+    "automatic-speech-recognition",
+    "audio-to-audio",
+    "speech-segmentation",
+    "audio-classification",
+}
+
+IMAGE_INPUTS = {
+    "image-classification",
+    "image-segmentation",
+    "image-to-text",
+    "object-detection",
+}
+
+TEXT_INPUTS = {
+    "conversational",
+    "feature-extraction",
+    "question-answering",
+    "sentence-similarity",
+    "fill-mask",
+    "table-question-answering",
+    "structured-data-classification",
+    "summarization",
+    "text2text-generation",
+    "text-classification",
+    "text-to-image",
+    "text-to-speech",
+    "token-classification",
+    "zero-shot-classification",
+}
+
+
 def normalize_payload(
     bpayload: bytes, task: str, sampling_rate: Optional[int] = None
 ) -> Tuple[Any, Dict]:
-    if task in {
-        "automatic-speech-recognition",
-        "audio-to-audio",
-        "speech-segmentation",
-    }:
+    if task in AUDIO_INPUTS:
         if sampling_rate is None:
             raise EnvironmentError(
                 "We cannot normalize audio file if we don't know the sampling rate"
             )
         outputs = normalize_payload_audio(bpayload, sampling_rate)
         return outputs
-    elif task in {
-        "image-classification",
-        "image-to-text",
-    }:
+    elif task in IMAGE_INPUTS:
         return normalize_payload_image(bpayload)
-    else:
+    elif task in TEXT_INPUTS:
         return normalize_payload_nlp(bpayload, task)
+    else:
+        raise EnvironmentError(
+            f"The task `{task}` is not recognized by api-inference-community"
+        )
 
 
 def ffmpeg_convert(array: np.array, sampling_rate: int) -> bytes:
